@@ -192,7 +192,6 @@ class Model(object):
             cmeta_id = cmeta_id[1:]
 
         # Get variable by cmeta id string
-        assert isinstance(cmeta_id, str)
         try:
             return self._cmeta_id_to_variable[cmeta_id]
         except KeyError:
@@ -711,7 +710,7 @@ class Model(object):
 
     def add_rdf(self, rdf):
         """Takes an RDF string and stores it in the model's RDF graph."""
-        self.rdf.parse(StringIO(rdf))
+        self.rdf.parse(StringIO(rdf), format='xml')
 
     def transfer_cmeta_id(self, source, target):
         """
