@@ -215,9 +215,9 @@ class UnitStore(object):
         :raises KeyError: If the unit is not defined in this unit store.
         """
         if name in _UNSUPPORTED_UNITS:
-            raise KeyError('Unit ' + str(name) + 'is not currently supported by cellmlmanip.')
+            raise KeyError('Unit <' + str(name) + '> is not currently supported by cellmlmanip.')
         elif name not in self._known_units:
-            raise KeyError('Unknown unit ' + str(name) + '.')
+            raise KeyError('Unknown unit <' + str(name) + '>.')
 
         return getattr(self._registry, self._prefix_name(name))
 
@@ -290,6 +290,10 @@ class UnitStore(object):
         """
         assert isinstance(quantity, self._registry.Quantity)
         assert isinstance(unit, self._registry.Unit)
+        #  Trying to convert FROM dimensionless gives an error but we can convert TO it
+        if quantity.units == self._registry.dimensionless:
+            quantity, unit = 1 * unit, quantity.units
+            return quantity.magnitude / quantity.to(unit)
         return quantity.to(unit)
 
     def add_conversion_rule(self, from_unit, to_unit, rule):
